@@ -23,9 +23,9 @@ from warnings import catch_warnings
 from warnings import simplefilter
 import matplotlib.pyplot as plt
 from sklearn import preprocessing
-from sklearn.gaussian_process.kernels import Matern, ConstantKernel, RBF, ExpSineSquared, RationalQuadratic, WhiteKernel
+from sklearn.gaussian_process.kernels import Matern, RationalQuadratic
 import sys
-
+from mpl_toolkits.mplot3d import Axes3D
 
 # Define objective function
 
@@ -45,7 +45,7 @@ def functions(x, y, function):
     Returns
     -------
     TYPE float
-        Returns function value based on input x and y \.
+        Returns function value based on input x and y.
 
     '''
     if function == 'Beale':
@@ -82,10 +82,44 @@ def surrogate(model, XY):
         Returns mean and standard deviation arrays for evaluated points.
 
     '''
-    return model.predict(XY, return_std=True)
+    with catch_warnings():
+        # Ignore scaling warnings (not true)
+        simplefilter("ignore")
+        return model.predict(XY, return_std=True)
+
+
+def create_random(x_bounds, y_bounds, n_random):
+    '''
+    Uniformly creates the specified number of random points within specified bounds.
+
+    Parameters
+    ----------
+    x_bounds : list
+        Two element list of x-axis boundaries for the function.
+    y_bounds : list
+        Two element list of y-axis boundaries for the function.
+    n_random : int
+        Number of random points to be created.
+
+    Returns
+    -------
+    XYsamples : numpy array
+        Array of created random sample points.
+
+    '''
+    # Unpack bounds
+    x1, x2 = x_bounds
+    y1, y2 = y_bounds
+    
+    # Create random sample points
+    Xsamples = uniform(x1,x2, n_random)
+    Ysamples = uniform(y1,y2, n_random)
+    XYsamples=numpy.vstack((Xsamples, Ysamples)).T
+    
+    return XYsamples
 
 # Maximum probability of improvement acquisition function
-def acquisition(XY, x_bounds, y_bounds, e, model, max_min):
+def acquisition(XY, x_bounds, y_bounds, e, model, max_min, n_random):
     '''
     Creates sample points and finds the one most likely to improve the function when
     evaluating.
@@ -104,7 +138,9 @@ def acquisition(XY, x_bounds, y_bounds, e, model, max_min):
         Some Gaussian process model.
     max_min : str
         Specifies whether the algorithm is searching for maxima or minima.
-
+    n_random : int
+        Number of random points to be created.
+    
     Returns
     -------
     X_best : float
@@ -113,10 +149,7 @@ def acquisition(XY, x_bounds, y_bounds, e, model, max_min):
         y-coordinate of point with maximum probability of improvement.
 
     '''
-    # Unpack bounds
-    x1, x2 = x_bounds
-    y1, y2 = y_bounds
-    
+
     # Find the best surrogate mean found so far
     z_surrogate, _ = surrogate(model, XY)
     if max_min == 'maximum':
@@ -124,17 +157,8 @@ def acquisition(XY, x_bounds, y_bounds, e, model, max_min):
     if max_min == 'minimum':
         best = numpy.min(z_surrogate)
     
-    # Create random sample points
-    Xsamples = ([])
-    Ysamples = ([])
-    for i in range(100):
-        a = uniform(x1,x2)
-        Xsamples.append(a)
-        b = uniform(y1,y2)
-        Ysamples.append(b)
-    Xsamples = numpy.array(Xsamples)
-    Ysamples = numpy.array(Ysamples)
-    XYsamples=numpy.vstack((Xsamples, Ysamples)).T
+    #Extract random points
+    XYsamples = create_random(x_bounds, y_bounds, n_random)
     
     # Find the mean and standard deviation of the sample points
     mu, std = surrogate(model, XYsamples)
@@ -262,7 +286,7 @@ def fit_model(model, data_input, data_output):
     model.fit(data_input, data_output)
 
     
-def optimize(opt_func, aquisition_func, starting_n, x_bounds, y_bounds, iterations, e, model, max_min):
+def optimize(opt_func, aquisition_func, starting_n, n_random, x_bounds, y_bounds, iterations, e, model, max_min):
     '''
     
 
@@ -274,6 +298,8 @@ def optimize(opt_func, aquisition_func, starting_n, x_bounds, y_bounds, iteratio
         Function used to pick points to evaluate.
     starting_n : int
         Initial number of random points evaluated.
+    n_random : int
+        Number of random points to be created.
     x_bounds : list
         Two element list of x-axis boundaries for the function.
     y_bounds : list
@@ -301,7 +327,7 @@ def optimize(opt_func, aquisition_func, starting_n, x_bounds, y_bounds, iteratio
     
     for i in range(iterations):
         # Select the next point to sample
-        x, y, *rest= aquisition_func(XY, x_bounds, y_bounds, e, model, max_min)
+        x, y, *rest= aquisition_func(XY, x_bounds, y_bounds, e, model, max_min, n_random)
         XYmingi = numpy.array(([x, y]))
         XYmingi = XYmingi.reshape(1, -1)
         
@@ -331,7 +357,7 @@ def optimize(opt_func, aquisition_func, starting_n, x_bounds, y_bounds, iteratio
     
     return XY, z
     
-def results(opt_function, acquisition, starting_n, x_bounds, y_bounds, iterations, e, model, max_min): 
+def results(opt_function, acquisition, starting_n, n_random, x_bounds, y_bounds, iterations, e, model, max_min): 
     '''
     Returns the results of the optimization process
 
@@ -343,6 +369,8 @@ def results(opt_function, acquisition, starting_n, x_bounds, y_bounds, iteration
         Function used to pick points to evaluate.
     starting_n : int
         Initial number of random points evaluated.
+    n_random : int
+        Number of random points to be created.
     x_bounds : list
         Two element list of x-axis boundaries for the function.
     y_bounds : list
@@ -369,7 +397,7 @@ def results(opt_function, acquisition, starting_n, x_bounds, y_bounds, iteration
     #Start timer
     startTime = datetime.now()
     #Optimize and unpack XY and corresponding z
-    XY, z = optimize(opt_function, acquisition, starting_n, x_bounds, y_bounds, iterations, e, model, max_min)
+    XY, z = optimize(opt_function, acquisition, starting_n, n_random, x_bounds, y_bounds, iterations, e, model, max_min)
     # Find best result
     if max_min == 'maximum':
         index = (numpy.argwhere(z == numpy.max(z)))
@@ -379,7 +407,7 @@ def results(opt_function, acquisition, starting_n, x_bounds, y_bounds, iteration
         index = (numpy.argwhere(z == numpy.min(z)))
         z_best = numpy.min(z)
         ix = index[0,0]
-    x, y = XY[ix]
+    x_best, y_best = XY[ix]
     
     #Unpack all XY and z evaluated and plot as scatter plot
     Xfinal=([])
@@ -397,12 +425,12 @@ def results(opt_function, acquisition, starting_n, x_bounds, y_bounds, iteration
     
     #Print results and time taken
     print('')
-    print('The %s found is at x=%f, y=%f with a value of z=%f' % (max_min, x, y, z_best))
+    print('The %s found is at x=%f, y=%f with a value of z=%f' % (max_min, x_best, y_best, z_best))
     print('Time elapsed', datetime.now() - startTime)
     print('Time per iteration', (datetime.now() - startTime)/iterations)
-    return x, y, z_best
+    return x_best, y_best, z_best
 
-def Bayesian2D(x_bounds, y_bounds, starting_n, iterations, max_min, exploration, function = 'Rosenbrock' ):
+def Bayesian2D(x_bounds, y_bounds, starting_n, n_random, iterations, max_min, exploration, function = 'Rosenbrock' ):
     '''
     Combines all the functions in the package to find the maximum/minimum of any 2D
     function specified.
@@ -415,6 +443,8 @@ def Bayesian2D(x_bounds, y_bounds, starting_n, iterations, max_min, exploration,
         Two element list of y-axis boundaries for the function.
     starting_n : int
         Initial number of random points evaluated.
+    n_random : int
+        Number of random points to be created.
     iterations : int
         Number of times optimization is run.
     max_min : str
@@ -467,6 +497,7 @@ def Bayesian2D(x_bounds, y_bounds, starting_n, iterations, max_min, exploration,
     
     #Find results
     
-    return results(objective, acquisition, starting_n, x_bounds, y_bounds, iterations, e, model, max_min)
-
+    x, y, z_best = results(objective, acquisition, starting_n, n_random, x_bounds, y_bounds, iterations, e, model, max_min)
+    
+    return x, y, z_best
 
