@@ -14,7 +14,7 @@ def functions(x, y, function):
     Returns
     -------
     TYPE float
-        Returns function value based on input x and y \.
+        Returns function value based on input x and y.
 
     '''
     if function == 'Beale':
